MethodSelected class

Constructors

MethodSelected({String? vaultedToken, required String paymentMethodType})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
paymentMethodType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vaultedToken String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(covariant MethodSelected other) bool
The equality operator.
override