yuno library
Classes
- AndroidConfig
- Appearance
- Appearance customization settings for the Yuno SDK on iOS.
- EnrollmentArguments
- IosConfig
- Configuration options specific to iOS for the Yuno SDK.
- MethodSelected
- PaymentMethodConf
- SeamlessArguments
- StartPayment
- Yuno
-
The
Yunoclass provides an abstract interface for initializing and interacting with the Yuno SDK. - YunoConfig
- YunoEnrollmentListener
- A widget that listens for a token change and provides a child widget.
- YunoEnrollmentNotifier
- YunoEnrollmentState
- YunoMultiListener
- A widget that listens for a multiple states change and provides a child widget.
- YunoPaymentListener
- A widget that listens for a payment state change and provides a child widget.
- YunoPaymentMethodChannelFactory
- YunoMethodChannelFactory
- YunoPaymentMethods
- A Flutter widget that displays payment methods using a native iOS and Android views.
- YunoPaymentMethodSelectNotifier
- YunoPaymentMethodState
- YunoPaymentSelectNotifier
- YunoPaymentSelectState
Enums
- AndroidPlatformViewRenderType
- YunoLanguage
- Enum representing the languages supported by the Yuno SDK. Example usage:
- YunoStatus
Extensions
- EnrollmentArgumentsParser on EnrollmentArguments
- ParserAndroidConfig on AndroidConfig
- ParserYunoConfig on YunoConfig
- SeamlessParser on SeamlessArguments
- YunoReader on BuildContext
- An easy way to interact with the Yuno object directly from the BuildContext.
Typedefs
- YunoEnrollmentWidgetListener = void Function(BuildContext context, YunoEnrollmentState state)
-
Signature for the
listenerfunction which takes theBuildContextalong with thestateand is responsible for executing in response tostatechanges. - YunoPaymentMethodSelectedWidgetListener = void Function(BuildContext context, MethodSelected? methodSelected, double height)
-
Signature for the
listenerfunction which takes theBuildContextalong with themethodSelectedstate andheightand is responsible for executing in response to state changes. - YunoPaymentWidgetListener = void Function(BuildContext context, YunoPaymentState state)
-
Signature for the
listenerfunction which takes theBuildContextalong with thestateand is responsible for executing in response tostatechanges.
Exceptions / Errors
- YunoException
- YunoInvalidArguments
- YunoInvalidArguments
- YunoInvalidArguments
- YunoMethodNotImplemented
- YunoInvalidArguments
- YunoMissingParam
- YunoInvalidArguments
- YunoNotFoundError
- YunoInvalidArguments
- YunoNotSupport
- YunoInvalidArguments
- YunoTimeout
- YunoInvalidArguments
- YunoUnexpectedException
- YunoInvalidArguments